@@ -11,6 +11,7 @@ import warnings
 from dataclasses import dataclass
 from enum import IntEnum
 from typing import Optional, Set, TYPE_CHECKING
+
 if TYPE_CHECKING:
     import pint
 
@@ -439,20 +440,22 @@ class ML600:
 
         return self._validate_speed(str(seconds_per_stroke))
 
-    def _seconds_per_stroke_to_flowrate(self, second_per_stroke: pint.Quantity) -> float:
-        """ The inverse of flowrate_to_seconds_per_stroke(). Only internal use. """
+    def _seconds_per_stroke_to_flowrate(
+        self, second_per_stroke: pint.Quantity
+    ) -> float:
+        """The inverse of flowrate_to_seconds_per_stroke(). Only internal use."""
         flowrate = 1 / (second_per_stroke * self._steps_per_ml)
         return flowrate.to("ml/min")
 
     def _volume_to_step_position(self, volume_w_units: str) -> int:
-        """ Converts a volume to a step position. """
+        """Converts a volume to a step position."""
         # noinspection PyArgumentEqualDefault
         volume = flowchem_ureg(volume_w_units)
         steps = volume * self._steps_per_ml
         return round(steps.m_as("steps")) + self._offset_steps
 
     async def _to_step_position(self, position: int, speed: str = ""):
-        """ Absolute move to step position. """
+        """Absolute move to step position."""
         abs_move_cmd = Protocol1CommandTemplate(command="M", optional_parameter="S")
         return await self.send_command_and_read_reply(
             abs_move_cmd, str(position), self._validate_speed(speed)
@@ -467,11 +470,11 @@ class ML600:
         return str(current_steps / self._steps_per_ml)
 
     async def to_volume(self, target_volume: str, speed: str = ""):
-        """ Absolute move to volume provided. """
-        await self._to_step_position(self._volume_to_step_position(target_volume), speed)
-        logger.debug(
-            f"Pump {self.name} set to volume {target_volume} at speed {speed}"
+        """Absolute move to volume provided."""
+        await self._to_step_position(
+            self._volume_to_step_position(target_volume), speed
         )
+        logger.debug(f"Pump {self.name} set to volume {target_volume} at speed {speed}")
 
     async def pause(self):
         """Pause any running command."""
@@ -604,8 +607,15 @@ class ML600:
         if wait:
             await self.wait_until_idle()
 
-    async def transfer(self, volume: str, from_valve: ValvePositionName, to_valve: ValvePositionName,
-                       flowrate_in: str = "1 ml/min", flowrate_out: str = "1 ml/min", wait: bool = False):
+    async def transfer(
+        self,
+        volume: str,
+        from_valve: ValvePositionName,
+        to_valve: ValvePositionName,
+        flowrate_in: str = "1 ml/min",
+        flowrate_out: str = "1 ml/min",
+        wait: bool = False,
+    ):
         """Move liquid from place to place."""
         await self.pickup(volume, from_valve, flowrate_in, wait=True)
         await self.deliver(volume, to_valve, flowrate_out, wait=wait)
