@@ -1,6 +1,8 @@
+""" A vessel, optionally with info on the chemical input contained. """
 from typing import Optional
+from ord_schema.proto.reaction_pb2 import ReactionInput
 
-from flowchem.components.stdlib import Component
+from flowchem.components.properties import Component
 
 
 class Vessel(Component):
@@ -19,4 +21,11 @@ class Vessel(Component):
     def __init__(self, description: Optional[str] = None, name: Optional[str] = None):
         super().__init__(name=name)
         self.description = description
-        self._visualization_shape = "cylinder"
+        self.chemical = None
+
+    def _validate(self, dry_run):
+        # If chemical info are provided, they should be ReactionInput
+        if self.chemical is not None:
+            assert isinstance(
+                self.chemical, ReactionInput
+            ), "Vessel have a ReactionInput"
