@@ -1,4 +1,4 @@
-from .apparatus import Apparatus
 from .experiment import Experiment
 from .protocol import Protocol
 from .execute import Datapoint
+from .graph import DeviceGraph
